Class: Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaDataStreamWebStreamData
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaDataStreamWebStreamData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsadmin_v1beta/classes.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb
Overview
Data specific to web streams.
Instance Attribute Summary collapse
-
#default_uri ⇒ String
Domain name of the web app being measured, or empty.
-
#firebase_app_id ⇒ String
Output only.
-
#measurement_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAnalyticsAdminV1betaDataStreamWebStreamData
constructor
A new instance of GoogleAnalyticsAdminV1betaDataStreamWebStreamData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAnalyticsAdminV1betaDataStreamWebStreamData
Returns a new instance of GoogleAnalyticsAdminV1betaDataStreamWebStreamData.
1365 1366 1367 |
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_uri ⇒ String
Domain name of the web app being measured, or empty. Example: "http://www.
google.com", "https://www.google.com"
Corresponds to the JSON property defaultUri
1352 1353 1354 |
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1352 def default_uri @default_uri end |
#firebase_app_id ⇒ String
Output only. ID of the corresponding web app in Firebase, if any. This ID can
change if the web app is deleted and recreated.
Corresponds to the JSON property firebaseAppId
1358 1359 1360 |
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1358 def firebase_app_id @firebase_app_id end |
#measurement_id ⇒ String
Output only. Analytics Measurement ID. Example: "G-1A2BCD345E"
Corresponds to the JSON property measurementId
1363 1364 1365 |
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1363 def measurement_id @measurement_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1370 1371 1372 1373 1374 |
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1370 def update!(**args) @default_uri = args[:default_uri] if args.key?(:default_uri) @firebase_app_id = args[:firebase_app_id] if args.key?(:firebase_app_id) @measurement_id = args[:measurement_id] if args.key?(:measurement_id) end |