Class: Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaGoogleAdsLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1beta/classes.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb

Overview

A link between a Google Analytics property and a Google Ads account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1betaGoogleAdsLink

Returns a new instance of GoogleAnalyticsAdminV1betaGoogleAdsLink.



1458
1459
1460
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ads_personalization_enabledBoolean Also known as: ads_personalization_enabled?

Enable personalized advertising features with this integration. Automatically publish my Google Analytics audience lists and Google Analytics remarketing events/parameters to the linked Google Ads account. If this field is not set on create/update, it will be defaulted to true. Corresponds to the JSON property adsPersonalizationEnabled

Returns:

  • (Boolean)


1422
1423
1424
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1422

def ads_personalization_enabled
  @ads_personalization_enabled
end

#can_manage_clientsBoolean Also known as: can_manage_clients?

Output only. If true, this link is for a Google Ads manager account. Corresponds to the JSON property canManageClients

Returns:

  • (Boolean)


1428
1429
1430
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1428

def can_manage_clients
  @can_manage_clients
end

#create_timeString

Output only. Time when this link was originally created. Corresponds to the JSON property createTime

Returns:

  • (String)


1434
1435
1436
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1434

def create_time
  @create_time
end

#creator_email_addressString

Output only. Email address of the user that created the link. An empty string will be returned if the email address can't be retrieved. Corresponds to the JSON property creatorEmailAddress

Returns:

  • (String)


1440
1441
1442
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1440

def creator_email_address
  @creator_email_address
end

#customer_idString

Immutable. Google Ads customer ID. Corresponds to the JSON property customerId

Returns:

  • (String)


1445
1446
1447
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1445

def customer_id
  @customer_id
end

#nameString

Identifier. Format: properties/propertyId/googleAdsLinks/googleAdsLinkId Note: googleAdsLinkId is not the Google Ads customer ID. Corresponds to the JSON property name

Returns:

  • (String)


1451
1452
1453
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1451

def name
  @name
end

#update_timeString

Output only. Time when this link was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1456
1457
1458
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1456

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1463
1464
1465
1466
1467
1468
1469
1470
1471
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1463

def update!(**args)
  @ads_personalization_enabled = args[:ads_personalization_enabled] if args.key?(:ads_personalization_enabled)
  @can_manage_clients = args[:can_manage_clients] if args.key?(:can_manage_clients)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator_email_address = args[:creator_email_address] if args.key?(:creator_email_address)
  @customer_id = args[:customer_id] if args.key?(:customer_id)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end