Class: Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaKeyEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1beta/classes.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb

Overview

A key event in a Google Analytics property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1betaKeyEvent

Returns a new instance of GoogleAnalyticsAdminV1betaKeyEvent.



1522
1523
1524
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#counting_methodString

Required. The method by which Key Events will be counted across multiple events within a session. Corresponds to the JSON property countingMethod

Returns:

  • (String)


1482
1483
1484
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1482

def counting_method
  @counting_method
end

#create_timeString

Output only. Time when this key event was created in the property. Corresponds to the JSON property createTime

Returns:

  • (String)


1487
1488
1489
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1487

def create_time
  @create_time
end

#customBoolean Also known as: custom?

Output only. If set to true, this key event refers to a custom event. If set to false, this key event refers to a default event in GA. Default events typically have special meaning in GA. Default events are usually created for you by the GA system, but in some cases can be created by property admins. Custom events count towards the maximum number of custom key events that may be created per property. Corresponds to the JSON property custom

Returns:

  • (Boolean)


1497
1498
1499
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1497

def custom
  @custom
end

#default_valueGoogle::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaKeyEventDefaultValue

Defines a default value/currency for a key event. Corresponds to the JSON property defaultValue



1503
1504
1505
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1503

def default_value
  @default_value
end

#deletableBoolean Also known as: deletable?

Output only. If set to true, this event can be deleted. Corresponds to the JSON property deletable

Returns:

  • (Boolean)


1508
1509
1510
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1508

def deletable
  @deletable
end

#event_nameString

Immutable. The event name for this key event. Examples: 'click', 'purchase' Corresponds to the JSON property eventName

Returns:

  • (String)


1514
1515
1516
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1514

def event_name
  @event_name
end

#nameString

Output only. Resource name of this key event. Format: properties/property/ keyEvents/key_event Corresponds to the JSON property name

Returns:

  • (String)


1520
1521
1522
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1520

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1527
1528
1529
1530
1531
1532
1533
1534
1535
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1527

def update!(**args)
  @counting_method = args[:counting_method] if args.key?(:counting_method)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom = args[:custom] if args.key?(:custom)
  @default_value = args[:default_value] if args.key?(:default_value)
  @deletable = args[:deletable] if args.key?(:deletable)
  @event_name = args[:event_name] if args.key?(:event_name)
  @name = args[:name] if args.key?(:name)
end