Class: Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaMeasurementProtocolSecret

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1beta/classes.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb

Overview

A secret value used for sending hits to Measurement Protocol.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1betaMeasurementProtocolSecret

Returns a new instance of GoogleAnalyticsAdminV1betaMeasurementProtocolSecret.



1878
1879
1880
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. Human-readable display name for this secret. Corresponds to the JSON property displayName

Returns:

  • (String)


1862
1863
1864
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1862

def display_name
  @display_name
end

#nameString

Identifier. Resource name of this secret. This secret may be a child of any type of stream. Format: properties/property/dataStreams/dataStream/ measurementProtocolSecrets/measurementProtocolSecret Corresponds to the JSON property name

Returns:

  • (String)


1869
1870
1871
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1869

def name
  @name
end

#secret_valueString

Output only. The measurement protocol secret value. Pass this value to the api_secret field of the Measurement Protocol API when sending hits to this secret's parent property. Corresponds to the JSON property secretValue

Returns:

  • (String)


1876
1877
1878
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1876

def secret_value
  @secret_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1883
1884
1885
1886
1887
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1883

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @secret_value = args[:secret_value] if args.key?(:secret_value)
end