Class: Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaProperty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1beta/classes.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb

Overview

A resource message representing a Google Analytics property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1betaProperty

Returns a new instance of GoogleAnalyticsAdminV1betaProperty.



1999
2000
2001
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountString

Immutable. The resource name of the parent account Format: accounts/ account_id Example: "accounts/123" Corresponds to the JSON property account

Returns:

  • (String)


1923
1924
1925
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1923

def 
  @account
end

#create_timeString

Output only. Time when the entity was originally created. Corresponds to the JSON property createTime

Returns:

  • (String)


1928
1929
1930
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1928

def create_time
  @create_time
end

#currency_codeString

The currency type used in reports involving monetary values. Format: https:// en.wikipedia.org/wiki/ISO_4217 Examples: "USD", "EUR", "JPY" Corresponds to the JSON property currencyCode

Returns:

  • (String)


1934
1935
1936
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1934

def currency_code
  @currency_code
end

#delete_timeString

Output only. If set, the time at which this property was trashed. If not set, then this property is not currently in the trash can. Corresponds to the JSON property deleteTime

Returns:

  • (String)


1940
1941
1942
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1940

def delete_time
  @delete_time
end

#display_nameString

Required. Human-readable display name for this property. The max allowed display name length is 100 UTF-16 code units. Corresponds to the JSON property displayName

Returns:

  • (String)


1946
1947
1948
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1946

def display_name
  @display_name
end

#expire_timeString

Output only. If set, the time at which this trashed property will be permanently deleted. If not set, then this property is not currently in the trash can and is not slated to be deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


1953
1954
1955
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1953

def expire_time
  @expire_time
end

#industry_categoryString

Industry associated with this property Example: AUTOMOTIVE, FOOD_AND_DRINK Corresponds to the JSON property industryCategory

Returns:

  • (String)


1958
1959
1960
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1958

def industry_category
  @industry_category
end

#nameString

Identifier. Resource name of this property. Format: properties/property_id Example: "properties/1000" Corresponds to the JSON property name

Returns:

  • (String)


1964
1965
1966
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1964

def name
  @name
end

#parentString

Immutable. Resource name of this property's logical parent. Note: The Property- Moving UI can be used to change the parent. Format: accounts/account, properties/property Example: "accounts/100", "properties/101" Corresponds to the JSON property parent

Returns:

  • (String)


1971
1972
1973
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1971

def parent
  @parent
end

#property_typeString

Immutable. The property type for this Property resource. When creating a property, if the type is "PROPERTY_TYPE_UNSPECIFIED", then "ORDINARY_PROPERTY" will be implied. Corresponds to the JSON property propertyType

Returns:

  • (String)


1978
1979
1980
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1978

def property_type
  @property_type
end

#service_levelString

Output only. The Google Analytics service level that applies to this property. Corresponds to the JSON property serviceLevel

Returns:

  • (String)


1983
1984
1985
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1983

def service_level
  @service_level
end

#time_zoneString

Required. Reporting Time Zone, used as the day boundary for reports, regardless of where the data originates. If the time zone honors DST, Analytics will automatically adjust for the changes. NOTE: Changing the time zone only affects data going forward, and is not applied retroactively. Format: https://www.iana.org/time-zones Example: "America/Los_Angeles" Corresponds to the JSON property timeZone

Returns:

  • (String)


1992
1993
1994
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1992

def time_zone
  @time_zone
end

#update_timeString

Output only. Time when entity payload fields were last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1997
1998
1999
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 1997

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2004

def update!(**args)
  @account = args[:account] if args.key?(:account)
  @create_time = args[:create_time] if args.key?(:create_time)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @industry_category = args[:industry_category] if args.key?(:industry_category)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @property_type = args[:property_type] if args.key?(:property_type)
  @service_level = args[:service_level] if args.key?(:service_level)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @update_time = args[:update_time] if args.key?(:update_time)
end