Class: Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaPropertySummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1beta/classes.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb

Overview

A virtual resource representing metadata for a Google Analytics property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1betaPropertySummary

Returns a new instance of GoogleAnalyticsAdminV1betaPropertySummary.



2055
2056
2057
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_editBoolean Also known as: can_edit?

If true, then the user has a Google Analytics role that permits them to edit the property. Corresponds to the JSON property canEdit

Returns:

  • (Boolean)


2029
2030
2031
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2029

def can_edit
  @can_edit
end

#display_nameString

Display name for the property referred to in this property summary. Corresponds to the JSON property displayName

Returns:

  • (String)


2035
2036
2037
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2035

def display_name
  @display_name
end

#parentString

Resource name of this property's logical parent. Note: The Property-Moving UI can be used to change the parent. Format: accounts/account, properties/ property Example: "accounts/100", "properties/200" Corresponds to the JSON property parent

Returns:

  • (String)


2042
2043
2044
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2042

def parent
  @parent
end

#propertyString

Resource name of property referred to by this property summary Format: properties/property_id Example: "properties/1000" Corresponds to the JSON property property

Returns:

  • (String)


2048
2049
2050
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2048

def property
  @property
end

#property_typeString

The property's property type. Corresponds to the JSON property propertyType

Returns:

  • (String)


2053
2054
2055
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2053

def property_type
  @property_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2060
2061
2062
2063
2064
2065
2066
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2060

def update!(**args)
  @can_edit = args[:can_edit] if args.key?(:can_edit)
  @display_name = args[:display_name] if args.key?(:display_name)
  @parent = args[:parent] if args.key?(:parent)
  @property = args[:property] if args.key?(:property)
  @property_type = args[:property_type] if args.key?(:property_type)
end