Class: Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaRunAccessReportRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1beta/classes.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb

Overview

The request for a Data Access Record Report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1betaRunAccessReportRequest

Returns a new instance of GoogleAnalyticsAdminV1betaRunAccessReportRequest.



2205
2206
2207
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_rangesArray<Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaAccessDateRange>

Date ranges of access records to read. If multiple date ranges are requested, each response row will contain a zero based date range index. If two date ranges overlap, the access records for the overlapping days is included in the response rows for both date ranges. Requests are allowed up to 2 date ranges. Corresponds to the JSON property dateRanges



2116
2117
2118
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2116

def date_ranges
  @date_ranges
end

#dimension_filterGoogle::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaAccessFilterExpression

Expresses dimension or metric filters. The fields in the same expression need to be either all dimensions or all metrics. Corresponds to the JSON property dimensionFilter



2122
2123
2124
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2122

def dimension_filter
  @dimension_filter
end

#dimensionsArray<Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaAccessDimension>

The dimensions requested and displayed in the response. Requests are allowed up to 9 dimensions. Corresponds to the JSON property dimensions



2128
2129
2130
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2128

def dimensions
  @dimensions
end

#expand_groupsBoolean Also known as: expand_groups?

Optional. Decides whether to return the users within user groups. This field works only when include_all_users is set to true. If true, it will return all users with access to the specified property or account. If false, only the users with direct access will be returned. Corresponds to the JSON property expandGroups

Returns:

  • (Boolean)


2136
2137
2138
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2136

def expand_groups
  @expand_groups
end

#include_all_usersBoolean Also known as: include_all_users?

Optional. Determines whether to include users who have never made an API call in the response. If true, all users with access to the specified property or account are included in the response, regardless of whether they have made an API call or not. If false, only the users who have made an API call will be included. Corresponds to the JSON property includeAllUsers

Returns:

  • (Boolean)


2146
2147
2148
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2146

def include_all_users
  @include_all_users
end

#limitFixnum

The number of rows to return. If unspecified, 10,000 rows are returned. The API returns a maximum of 100,000 rows per request, no matter how many you ask for. limit must be positive. The API may return fewer rows than the requested limit, if there aren't as many remaining rows as the limit. For instance, there are fewer than 300 possible values for the dimension country, so when reporting on only country, you can't get more than 300 rows, even if you set limit to a higher value. To learn more about this pagination parameter, see Pagination. Corresponds to the JSON property limit

Returns:

  • (Fixnum)


2160
2161
2162
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2160

def limit
  @limit
end

#metric_filterGoogle::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaAccessFilterExpression

Expresses dimension or metric filters. The fields in the same expression need to be either all dimensions or all metrics. Corresponds to the JSON property metricFilter



2166
2167
2168
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2166

def metric_filter
  @metric_filter
end

#metricsArray<Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaAccessMetric>

The metrics requested and displayed in the response. Requests are allowed up to 10 metrics. Corresponds to the JSON property metrics



2172
2173
2174
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2172

def metrics
  @metrics
end

#offsetFixnum

The row count of the start row. The first row is counted as row 0. If offset is unspecified, it is treated as 0. If offset is zero, then this method will return the first page of results with limit entries. To learn more about this pagination parameter, see Pagination. Corresponds to the JSON property offset

Returns:

  • (Fixnum)


2181
2182
2183
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2181

def offset
  @offset
end

#order_bysArray<Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaAccessOrderBy>

Specifies how rows are ordered in the response. Corresponds to the JSON property orderBys



2186
2187
2188
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2186

def order_bys
  @order_bys
end

#return_entity_quotaBoolean Also known as: return_entity_quota?

Toggles whether to return the current state of this Analytics Property's quota. Quota is returned in AccessQuota. For account-level requests, this field must be false. Corresponds to the JSON property returnEntityQuota

Returns:

  • (Boolean)


2193
2194
2195
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2193

def return_entity_quota
  @return_entity_quota
end

#time_zoneString

This request's time zone if specified. If unspecified, the property's time zone is used. The request's time zone is used to interpret the start & end dates of the report. Formatted as strings from the IANA Time Zone database ( https://www.iana.org/time-zones); for example "America/New_York" or "Asia/ Tokyo". Corresponds to the JSON property timeZone

Returns:

  • (String)


2203
2204
2205
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2203

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2210

def update!(**args)
  @date_ranges = args[:date_ranges] if args.key?(:date_ranges)
  @dimension_filter = args[:dimension_filter] if args.key?(:dimension_filter)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @expand_groups = args[:expand_groups] if args.key?(:expand_groups)
  @include_all_users = args[:include_all_users] if args.key?(:include_all_users)
  @limit = args[:limit] if args.key?(:limit)
  @metric_filter = args[:metric_filter] if args.key?(:metric_filter)
  @metrics = args[:metrics] if args.key?(:metrics)
  @offset = args[:offset] if args.key?(:offset)
  @order_bys = args[:order_bys] if args.key?(:order_bys)
  @return_entity_quota = args[:return_entity_quota] if args.key?(:return_entity_quota)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end