Class: Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaRunAccessReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1beta/classes.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb

Overview

The customized Data Access Record Report response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1betaRunAccessReportResponse

Returns a new instance of GoogleAnalyticsAdminV1betaRunAccessReportResponse.



2267
2268
2269
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2267

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_headersArray<Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaAccessDimensionHeader>

The header for a column in the report that corresponds to a specific dimension. The number of DimensionHeaders and ordering of DimensionHeaders matches the dimensions present in rows. Corresponds to the JSON property dimensionHeaders



2235
2236
2237
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2235

def dimension_headers
  @dimension_headers
end

#metric_headersArray<Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaAccessMetricHeader>

The header for a column in the report that corresponds to a specific metric. The number of MetricHeaders and ordering of MetricHeaders matches the metrics present in rows. Corresponds to the JSON property metricHeaders



2242
2243
2244
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2242

def metric_headers
  @metric_headers
end

#quotaGoogle::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaAccessQuota

Current state of all quotas for this Analytics property. If any quota for a property is exhausted, all requests to that property will return Resource Exhausted errors. Corresponds to the JSON property quota



2249
2250
2251
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2249

def quota
  @quota
end

#row_countFixnum

The total number of rows in the query result. rowCount is independent of the number of rows returned in the response, the limit request parameter, and the offset request parameter. For example if a query returns 175 rows and includes limit of 50 in the API request, the response will contain rowCount of 175 but only 50 rows. To learn more about this pagination parameter, see Pagination. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


2260
2261
2262
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2260

def row_count
  @row_count
end

#rowsArray<Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaAccessRow>

Rows of dimension value combinations and metric values in the report. Corresponds to the JSON property rows



2265
2266
2267
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2265

def rows
  @rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2272
2273
2274
2275
2276
2277
2278
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2272

def update!(**args)
  @dimension_headers = args[:dimension_headers] if args.key?(:dimension_headers)
  @metric_headers = args[:metric_headers] if args.key?(:metric_headers)
  @quota = args[:quota] if args.key?(:quota)
  @row_count = args[:row_count] if args.key?(:row_count)
  @rows = args[:rows] if args.key?(:rows)
end