Class: Google::Apis::AnalyticsadminV1beta::GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsadmin_v1beta/classes.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb,
lib/google/apis/analyticsadmin_v1beta/representations.rb

Overview

Request message for SearchChangeHistoryEvents RPC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsRequest

Returns a new instance of GoogleAnalyticsAdminV1betaSearchChangeHistoryEventsRequest.



2346
2347
2348
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionArray<String>

Optional. If set, only return changes that match one or more of these types of actions. Corresponds to the JSON property action

Returns:

  • (Array<String>)


2297
2298
2299
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2297

def action
  @action
end

#actor_emailArray<String>

Optional. If set, only return changes if they are made by a user in this list. Corresponds to the JSON property actorEmail

Returns:

  • (Array<String>)


2302
2303
2304
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2302

def actor_email
  @actor_email
end

#earliest_change_timeString

Optional. If set, only return changes made after this time (inclusive). Corresponds to the JSON property earliestChangeTime

Returns:

  • (String)


2307
2308
2309
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2307

def earliest_change_time
  @earliest_change_time
end

#latest_change_timeString

Optional. If set, only return changes made before this time (inclusive). Corresponds to the JSON property latestChangeTime

Returns:

  • (String)


2312
2313
2314
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2312

def latest_change_time
  @latest_change_time
end

#page_sizeFixnum

Optional. The maximum number of ChangeHistoryEvent items to return. If unspecified, at most 50 items will be returned. The maximum value is 200 ( higher values will be coerced to the maximum). Note that the service may return a page with fewer items than this value specifies (potentially even zero), and that there still may be additional pages. If you want a particular number of items, you'll need to continue requesting additional pages using page_token until you get the needed number. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


2323
2324
2325
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2323

def page_size
  @page_size
end

#page_tokenString

Optional. A page token, received from a previous SearchChangeHistoryEvents call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to SearchChangeHistoryEvents must match the call that provided the page token. Corresponds to the JSON property pageToken

Returns:

  • (String)


2331
2332
2333
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2331

def page_token
  @page_token
end

#propertyString

Optional. Resource name for a child property. If set, only return changes made to this property or its child resources. Format: properties/propertyId Example: properties/100 Corresponds to the JSON property property

Returns:

  • (String)


2338
2339
2340
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2338

def property
  @property
end

#resource_typeArray<String>

Optional. If set, only return changes if they are for a resource that matches at least one of these types. Corresponds to the JSON property resourceType

Returns:

  • (Array<String>)


2344
2345
2346
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2344

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
# File 'lib/google/apis/analyticsadmin_v1beta/classes.rb', line 2351

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @actor_email = args[:actor_email] if args.key?(:actor_email)
  @earliest_change_time = args[:earliest_change_time] if args.key?(:earliest_change_time)
  @latest_change_time = args[:latest_change_time] if args.key?(:latest_change_time)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @property = args[:property] if args.key?(:property)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end